# -*- coding: utf-8 -*-
"""About blackblox.py

This module contains metadata about blackblox.py, which is used in the generation 
of output spreadsheets in io_functions.py
"""

about_blackblox = {
    "name": "blackblox.py",
    "version": "0.3",
    "url": "https://pypi.org/project/blackblox/",
    "documentation_url": "https://concoctions.org/blackblox/",
    "github_url": "https://github.com/concoctions/BlackBlox",
    "creator": "Ir. S.E. Tanzer",
    "affiliation": (
        "Energy & Industry Group, "
        "Department of Engineering Systems and Services, "
        "Facult of Technology Policy, and Management, "
        "Delft University of Technology, "
        "The Netherlands"),
    "license": "GPL v3",
}
